# Gaia Boat - communication module

## About the Gaia Boat

The Gaia Boat is an autonomous boat designed to collect trash from a lake’s shore. It uses image processing to detect obstacles and trash, an app for tracing routes and a series of other embedded software for controlling the hardware.

## Other Gaia Boat’s software links

- [gaia router](https://github.com/gaia-boat/router)
- [gaia control](https://github.com/gaia-boat/control)
- [gaia app](https://github.com/gaia-boat/app)
- [gaia communication](https://github.com/gaia-boat/communication)
- [gaia image processing](https://github.com/gaia-boat/image-processing)

## Communication module

### Usage and installation

#### Usage

This module is used to establish communication between the Raspberry Pi 3 and a ASP module. With both of them having different electronics and sensors attached like GPS, MPU and Bluetooth.

#### Installation

To install the package you must install if through pip, using the following command:

```shell
pip install gaia-communication
```

If you want to upgrade its version you must use:

```shell
pip install --upgrade gaia-communication
```

